Functions
=====

Test

proper:

.. automodule:: atmosphyre.dispersion_analysis
   :members:
   :special-members:
   :member-order: bysource

side: 

.. automodule:: atmosphyre.dispersion_functions
   :members:
   :private-members:
   :special-members:
